/*-- This model is the property of Cypress Semiconductor Corp.
-- and is protected by the US copyright laws, any unauthorized
-- copying and distribution is proibited.
-- Cypress reserves the right to change any of the functional 
-- specifications without any prior notice.
-- Cypress is not liable for any damages which may result from
-- the use of this functional model.
----------------------------------------------------------------------
-- File name : config.v
----------------------------------------------------------------------
-- Functionality : Timing and Configuration (General)
--               for FM16W08 chip behavioral Verilog model 
-- Source:  CYPRESS Data Sheet : "FM16W08 64Kbit F-RAM Memory" 
-----------------------------------------------------------------------
-- Developed by CYPRESS SEMICONDUCTOR
--
-- version |     author       | mod date | changes made
--    1.0         MEDU          03/27/14    New Model
------------------------------------------------------------------------
-- PART DESCRIPTION :
-- Part:        Timing F-RAM FM16W08
--
-- Descripton:  Contains Testbench for F-RAM features for  FM16W08
------------------------------------------------------------------------ */
// uncomment for 3.0V - 5.5V range. Comment for 2.7V - 3.0V range.
`define   VDD_3V_5p5V

// uncommented for 2.7V - 3.0V range. Comment for 3.0V - 5.5V range.
//`define   VDD_2p7V_3p0V

`ifdef VDD_2p7V_3p0V

`define tWC      145       // Write Cycle time
`define tWP      50        // Write Enable Pulse Width 
`define tCW      80        // Chip Enable to Write Enable High
`define tDS      40        // Data Input Setup Time
`define tWZ      15        // Write Enable Low to Output High Z
`define tHZ      15        // Chip Enable to Output High-Z   
`define tOHZ     15        // Output Enable High to Output High-Z  
`define tAS       0        // Address Setup Time (to /CE low)
`define tAH      15        // Address Hold Time (/CE-controlled) 
`define tOE      15        // Output Enable Access Time
`define tDH       0        // Data Input Hold Time
`define tWS       0        // Write Enable to /CE Low Setup Time

      // COMMON parameters
`define Trc  145  // Address or CE Cycle Time min
`define Tca   80  // CE Low Time min
`define Tpc   65  // CE High Time min (precharge time)
`define Tas    0  // Addr Setup Time min (relative to CE falling edge)
`define Tah   15  // Addr Hold Time min (relative to CE falling edge)
`define Thz   15  // CE High to Q High-Z max

// READ parameters
`define Tce   80    // CE Access Time max
`define Toe   15    // OE Access Time max
`define Tohz  15    // OE High to Q High-Z max
`define Tdummy 0.1  // Should never be used

// WRITE parameters
`define Twp   50    // WE Pulse Width min
`define Tcw   80    // CE Low to WE High min
`define Tds   40    // Data Setup Time to end of Write
`define Tdh    0    // Data Hold Time to end of Write
`define Twz   15    // WE Low to Q High-Z max
`define Twx   10    // WE High to Q Active min

`endif

`ifdef VDD_3V_5p5V

`define tWC      130       // Write Cycle time
`define tWP      40        // Write Enable Pulse Width 
`define tCW      70        // Chip Enable to Write Enable High
`define tDS      30        // Data Input Setup Time
`define tWZ      15        // Write Enable Low to Output High Z
`define tHZ      15        // Chip Enable to Output High-Z   
`define tOHZ     15        // Output Enable High to Output High-Z  
`define tAS       0        // Address Setup Time (to /CE low)
`define tAH      15        // Address Hold Time (/CE-controlled) 
`define tOE      12        // Output Enable Access Time
`define tDH       0        // Data Input Hold Time
`define tWS       0        // Write Enable to /CE Low Setup Time

      // COMMON parameters
`define Trc  130  // Address or CE Cycle Time min
`define Tca   70  // CE Low Time min
`define Tpc   60  // CE High Time min (precharge time)
`define Tas    0  // Addr Setup Time min (relative to CE falling edge)
`define Tah   15  // Addr Hold Time min (relative to CE falling edge)
`define Thz   15  // CE High to Q High-Z max

// READ parameters
`define Tce   70    // CE Access Time max
`define Toe   12    // OE Access Time max
`define Tohz  15    // OE High to Q High-Z max
`define Tdummy 0.1  // Should never be used

// WRITE parameters
`define Twp   40    // WE Pulse Width min
`define Tcw   70    // CE Low to WE High min
`define Tds   30    // Data Setup Time to end of Write
`define Tdh    0    // Data Hold Time to end of Write
`define Twz   15    // WE Low to Q High-Z max
`define Twx   10    // WE High to Q Active min

`endif

//_______________________________________________________________________
//  Uncomment only if you want to initialize memory with values from a file
//
`define       initMemFile     "init.dat"
